#!/usr/bin/env python
# -*- coding: utf-8 -*-

from os.path import isfile
from subprocess import call, PIPE, CalledProcessError, check_output

def _cmd_exists(cmd):
    return call("type " + cmd, shell=True,
        stdout=PIPE, stderr=PIPE) == 0

def _get_dmi_info(name, fname):
    val = ''
    try:
        if _cmd_exists('sudo') and _cmd_exists('dmidecode'):
            val = check_output(['sudo', 'dmidecode', '-s', 'system-serial-number'])
        else:
            raise Exception('Missing binary')
    except:
        if isfile(fname):
            f = open(fname, 'r')
            val = f.readline()
            f.close
    return val.strip()

def dmidecode_info():
    data = {}
    data['serial_number'] = _get_dmi_info('system-serial-number', '/sys/devices/virtual/dmi/id/product_serial')
    data['manufacturer'] = _get_dmi_info('system-manufacturer', '/sys/devices/virtual/dmi/id/chassis_vendor')
    data['product_version'] = _get_dmi_info('product_version', '/sys/devices/virtual/dmi/id/product_version')
    data['product'] = _get_dmi_info('system-product-name', '/sys/devices/virtual/dmi/id/product_name')
    data['bios_date'] = _get_dmi_info('bios-release-date', '/sys/devices/virtual/dmi/id/bios_date')
    data['bios_vendor'] = _get_dmi_info('bios-vendor', '/sys/devices/virtual/dmi/id/bios_vendor')
    data['bios_version'] = _get_dmi_info('bios-version', '/sys/devices/virtual/dmi/id/bios_version')
    return data

if __name__ == "__main__":
    print dmidecode_info()



#!/usr/bin/env python

import psutil

def mem_status():
    data = {}
    data['vmem'] = dict(psutil.virtual_memory()._asdict())
    data['swap'] = dict(psutil.swap_memory()._asdict())
    return data

if __name__ == "__main__":
    print mem_status()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

def mem_info():
    data = {}
    with open('/proc/meminfo') as fp:
        for line in fp:
            cols = line.rstrip('\n').split(':')
            if not len(cols) > 1:
                continue
            if cols[0].strip() == 'MemTotal':
                data['mem_total_kb'] = int(cols[1].split()[0])
                break
    return data

if __name__ == "__main__":
    print mem_info()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import glob
import re

def _get_display_adapter(path):
    # Get pci bus, device and function
    pci = re.split(':|\.', path.replace('/sys/bus/pci/devices/0000:', ''))
    bus_num = pci[0]
    device_num = pci[1]
    device_func = '.' + pci[2]

    # Get vendor id
    f = open(path + '/vendor', 'r')
    vendor_id = f.readline().rstrip().replace('0x', '')
    f.close

    # Get device id
    f = open(path + '/device', 'r')
    device_id = f.readline().rstrip().replace('0x', '')
    f.close

    # Get boot display adapter
    f = open(path + '/boot_vga', 'r')
    boot_device = bool(f.readline().rstrip())
    f.close

    # Get vendor and device name
    vendor_name = ''
    device_name = ''
    no_cols = 1
    with open('/usr/share/hwdata/pci.ids') as f:
        for line in f:
            col = re.split('\s+', line, no_cols)
            if col[0] == vendor_id:
                vendor_name = col[1].rstrip()
                no_cols += 1
                continue
            if vendor_name != '' and col[1] == device_id:
                device_name = col[2].rstrip()
                break
            if vendor_name != '' and col[0] != '':
                break

    display_adapter = {
        'path': path,
        'pci': {
            'bus': bus_num,
            'device': device_num,
            'function': device_func
        },
        'vendor_id': vendor_id,
        'vendor_name': vendor_name,
        'device_id': device_id,
        'device_name': device_name,
        'boot_device': boot_device,
    };
    return display_adapter

def display_adapters():
    # Find display adapters
    data = {}
    data['display'] = []
    files = glob.glob('/sys/bus/pci/devices/*/class')
    for file in files:
        f = open(file, 'r')

        # Only consider devices with device class 0x030000
        if f.readline().rstrip() == '0x030000':
            data['display'].append(_get_display_adapter(file.replace('/class', '')))
        f.close()
    return data

if __name__ == "__main__":
    print display_adapters()



#!/usr/bin/env python

import os
import os.path

check_fs = [ 'ext3', 'ext4', 'xfs' ]

def _disk_usage(path):
    st = os.statvfs(path)
    free = st.f_bavail * st.f_frsize / 1024
    total = st.f_blocks * st.f_frsize / 1024
    used = (st.f_blocks - st.f_bfree) * st.f_frsize / 1024
    return {'free_kb': free, 'total_kb': total, 'used_kb': used}

def _get_mounts():
    mounts = []
    f = open('/proc/mounts', 'r')
    for line in f.readlines():
        cols = line.rstrip('\n').split(' ', 6)
        if cols[2] in check_fs and os.path.ismount(cols[1]):
            mounts.append(cols[1])
    return mounts

def disk_status():
    data = {'disk': {}}
    for mount in _get_mounts():
        data['disk'][mount] = _disk_usage(mount)
    return data

if __name__ == "__main__":
    print disk_status()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from subprocess import Popen, PIPE

def lsb_release():
    output = Popen(['lsb_release', '-a'], stdout=PIPE).communicate()[0]
    data = {}
    for line in output.split('\n'):
        col = line.split(':', 2)
        if len(col) < 2:
            continue
        key = col[0].strip()
        val = col[1].strip()
        if key == 'Distributor ID':
            data['os_distro'] = val
        elif key == 'Release':
            data['os_release'] = val
    return data

if __name__ == "__main__":
    print lsb_release()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

def cpu_info():
    f = open('/proc/cpuinfo', 'r')
    data = {
        'cpu_model': 'Unknown',
        'cpu_processors': 0,
        'cpu_threads_per_core': 0
    }

    cpu_id = None
    cpu_ids = { '0': None }
    for line in f.readlines():
        cols = line.split(':', 2)
        if len(cols) < 2:
            continue
        key = cols[0].strip()
        val = cols[1].strip()
        if key == 'model name':
            data['cpu_model'] = val.split('-')[0]
        elif key == 'processor':
            data['cpu_processors'] += 1
        elif key == 'physical id':
            cpu_id = val
            cpu_ids[cpu_id] = None
        elif key == 'cpu MHz':
            data['cpu_speed_mhz'] = int(float(val))
        elif key == 'core id':
            core_id = val
            if cpu_id == '0' and core_id == '0':
                data['cpu_threads_per_core'] += 1
        elif key == 'flags':
                data['cpu_flags'] = val.split()
        elif key == 'Features':
                data['cpu_flags'] = val.split()
    f.close()

    data['cpu_sockets'] = len(cpu_ids)
    if data['cpu_threads_per_core'] > 0:
        data['cpu_cores_per_socket'] = data['cpu_processors'] / data['cpu_sockets'] / data['cpu_threads_per_core']
    else:
        data['cpu_threads_per_core'] = 1
        data['cpu_cores_per_socket'] = 1

    return data

if __name__ == "__main__":
    print cpu_info()
